
/*******************************************************************************

 Copyright (c) 2009, Charles McGarvey
 All rights reserved.
 
 Redistribution   and   use  in  source  and  binary  forms,  with  or  without
 modification, are permitted provided that the following conditions are met:
 
   * Redistributions  of  source  code  must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   * Redistributions  in binary form must reproduce the above copyright notice,
     this  list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
 
 THIS  SOFTWARE  IS  PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND  ANY  EXPRESS  OR  IMPLIED  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN  NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 FOR  ANY  DIRECT,  INDIRECT,  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES  (INCLUDING,  BUT  NOT  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES;  LOSS  OF  USE,  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*******************************************************************************/

#ifndef _MOOF_EXCEPTION_HH_
#define _MOOF_EXCEPTION_HH_

#include <exception>
#include <boost/shared_ptr.hpp>


namespace Mf {


struct Exception : public std::exception
{
	enum
	{
		FILE_NOT_FOUND	= 1,
		OPENGL_ERROR	= 2,
		OPENAL_ERROR	= 3,
		SDL_ERROR		= 4
	};

	explicit Exception(unsigned error) :
		code(error) {}
	virtual ~Exception() throw() {}

	virtual void raise()
	{
		throw *this;
	}

	virtual const char* what() const throw()
	{
		switch (code)
		{
			case FILE_NOT_FOUND:
				return "file not found";
			case OPENGL_ERROR:
				return "opengl error";
			case OPENAL_ERROR:
				return "openal error";
			case SDL_ERROR:
				return "sdl error";
		}
		return "unknown error";
	}

	unsigned code;
};


} // namespace Mf

#endif // _MOOF_EXCEPTION_HH_

/** vim: set ts=4 sw=4 tw=80: *************************************************/

